#[non_exhaustive]pub enum Error {
NotFoundManifestDir,
InvalidManifest(String),
NotFound,
Io(Error),
Toml(TomlError),
}Expand description
An error that occurred when getting manifest.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFoundManifestDir
The CARGO_MANIFEST_DIR environment variable not found.
InvalidManifest(String)
The manifest is invalid for the following reason.
NotFound
The crate with the specified name not found. This error occurs only from find_crate.
Io(Error)
An error occurred while trying to open or to read the manifest file.
Toml(TomlError)
An error occurred while trying to parse the manifest file.